@@ -1,10 +1,10 @@
 package Net::Google::Code;
 
 use Moose;
-with 'Net::Google::Code::Role';
+with 'Net::Google::Code::TypicalRoles';
 use Scalar::Util qw/blessed/;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 has 'project' => (
     isa      => 'Str',
